@@ -245,8 +245,13 @@ class Manager(manager.Manager):
                      config.CONF.member_role_id)
             role = {'id': CONF.member_role_id,
                     'name': CONF.member_role_name}
-            self.driver.create_role(config.CONF.member_role_id, role)
-            #now that default role exists, the add should succeed
+            try:
+                self.driver.create_role(config.CONF.member_role_id, role)
+            except exception.Conflict:
+                LOG.info(_("Creating the default role %s failed because it "
+                           "was already created"),
+                         config.CONF.member_role_id)
+            # now that default role exists, the add should succeed
             self.driver.add_role_to_user_and_project(
                 user_id,
                 tenant_id,
