@@ -16,9 +16,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import collections
+
 from keystone.contrib import federation
 from keystone import exception
-from keystone.i18n import _
+from keystone.openstack.common.gettextutils import _
 from keystone.openstack.common import log
 
 
@@ -41,6 +43,23 @@ It is a dictionary with the following attributes:
 LOG = log.getLogger(__name__)
 
 
+def flatten(d, parent_key=''):
+    """Flatten a nested dictionary
+
+    Converts a dictionary with nested values to a single level flat
+    dictionary, with dotted notation for each key.
+
+    """
+    items = []
+    for k, v in d.items():
+        new_key = parent_key + '.' + k if parent_key else k
+        if isinstance(v, collections.MutableMapping):
+            items.extend(flatten(v, new_key).items())
+        else:
+            items.append((new_key, v))
+    return dict(items)
+
+
 def is_v3_token(token):
     # V3 token data are encapsulated into "token" key while
     # V2 token data are encapsulated into "access" key.
@@ -58,7 +77,7 @@ def v3_token_to_auth_context(token):
     if 'project' in token_data:
         creds['project_id'] = token_data['project']['id']
     else:
-        LOG.debug('RBAC: Proceeding without project')
+        LOG.debug(_('RBAC: Proceeding without project'))
     if 'domain' in token_data:
         creds['domain_id'] = token_data['domain']['id']
     if 'roles' in token_data:
@@ -102,7 +121,7 @@ def v2_token_to_auth_context(token):
     if 'tenant' in token_data['token']:
         creds['project_id'] = token_data['token']['tenant']['id']
     else:
-        LOG.debug('RBAC: Proceeding without tenant')
+        LOG.debug(_('RBAC: Proceeding without tenant'))
     if 'roles' in token_data['user']:
         creds['roles'] = [role['name'] for
                           role in token_data['user']['roles']]
