@@ -26,7 +26,7 @@ import eventlet
 import eventlet.wsgi
 import greenlet
 
-from keystone.i18n import _
+from keystone.openstack.common.gettextutils import _
 from keystone.openstack.common import log
 
 
@@ -69,29 +69,9 @@ class Server(object):
         self.cert_required = False
         self.keepalive = keepalive
         self.keepidle = keepidle
-        self.socket = None
 
     def start(self, key=None, backlog=128):
         """Run a WSGI server with the given application."""
-
-        if self.socket is None:
-            self.listen(key=key, backlog=backlog)
-
-        self.greenthread = self.pool.spawn(self._run,
-                                           self.application,
-                                           self.socket)
-
-    def listen(self, key=None, backlog=128):
-        """Create and start listening on socket.
-
-        Call before forking worker processes.
-
-        Raises Exception if this has already been called.
-        """
-
-        if self.socket is not None:
-            raise Exception(_('Server can only listen once.'))
-
         LOG.info(_('Starting %(arg0)s on %(host)s:%(port)s'),
                  {'arg0': sys.argv[0],
                   'host': self.host,
@@ -131,7 +111,9 @@ class Server(object):
                 _socket.setsockopt(socket.IPPROTO_TCP, socket.TCP_KEEPIDLE,
                                    self.keepidle)
 
-        self.socket = _socket
+        self.greenthread = self.pool.spawn(self._run,
+                                           self.application,
+                                           _socket)
 
     def set_ssl(self, certfile, keyfile=None, ca_certs=None,
                 cert_required=True):
@@ -145,9 +127,6 @@ class Server(object):
         if self.greenthread is not None:
             self.greenthread.kill()
 
-    def stop(self):
-        self.kill()
-
     def wait(self):
         """Wait until all servers have completed running."""
         try:
@@ -164,9 +143,6 @@ class Server(object):
             eventlet.wsgi.server(socket, application, custom_pool=self.pool,
                                  log=EventletFilteringLogger(logger),
                                  debug=False)
-        except greenlet.GreenletExit:
-            # Wait until all servers have completed running
-            pass
         except Exception:
             LOG.exception(_('Server error'))
             raise
