@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 # Copyright 2013 Metacloud, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,7 +16,8 @@
 
 from dogpile.cache import region
 
-from keystone.common.kvs.core import *  # noqa
+from keystone.common.kvs.core import *  # flake8: noqa
+from keystone.common.kvs.legacy import Base, DictKvs, INMEMDB  # flake8: noqa
 
 
 # NOTE(morganfainberg): Provided backends are registered here in the __init__
