@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 # Copyright 2013 Metacloud, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,21 +14,18 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-"""Keystone In-Memory Dogpile.cache backend implementation."""
+"""
+Keystone In-Memory Dogpile.cache backend implementation.
+"""
 
 import copy
 
 from dogpile.cache import api
-from oslo_log import versionutils
 
 
 NO_VALUE = api.NO_VALUE
 
 
-@versionutils.deprecated(
-    versionutils.deprecated.OCATA,
-    what='keystone.common.kvs.backends.MemoryBackend',
-    remove_in=+1)
 class MemoryBackend(api.CacheBackend):
     """A backend that uses a plain dictionary.
 
@@ -43,7 +42,6 @@ class MemoryBackend(api.CacheBackend):
             'keystone.common.kvs.Memory'
         )
     """
-
     def __init__(self, arguments):
         self._db = {}
 
