@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 # Copyright 2013 Metacloud, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -21,22 +23,22 @@ from dogpile.cache import api
 from dogpile.cache import proxy
 from dogpile.cache import region
 from dogpile.cache import util as dogpile_util
-from dogpile.util import nameregistry
-from oslo_log import log
-from oslo_log import versionutils
-from oslo_utils import importutils
-from oslo_utils import reflection
+from dogpile.core import nameregistry
+import six
 
-import keystone.conf
+from keystone.common import config
 from keystone import exception
-from keystone.i18n import _, _LI, _LW
+from keystone.openstack.common.gettextutils import _ # flake8: noqa
+from keystone.openstack.common import importutils
+from keystone.openstack.common import log
 
-__all__ = ('KeyValueStore', 'KeyValueStoreLock', 'LockTimeout',
-           'get_key_value_store')
+
+__all__ = ['KeyValueStore', 'KeyValueStoreLock', 'LockTimeout',
+           'get_key_value_store']
 
 
 BACKENDS_REGISTERED = False
-CONF = keystone.conf.CONF
+CONF = config.CONF
 KEY_VALUE_STORE_REGISTRY = weakref.WeakValueDictionary()
 LOCK_WINDOW = 1
 LOG = log.getLogger(__name__)
@@ -58,30 +60,13 @@ def _register_backends():
         for backend in CONF.kvs.backends:
             module, cls = backend.rsplit('.', 1)
             backend_name = prefix % cls
-            LOG.debug(('Registering Dogpile Backend %(backend_path)s as '
-                       '%(backend_name)s'),
+            LOG.debug(_('Registering Dogpile Backend %(backend_path)s as '
+                        '%(backend_name)s'),
                       {'backend_path': backend, 'backend_name': backend_name})
             region.register_backend(backend_name, module, cls)
         BACKENDS_REGISTERED = True
 
 
-def sha1_mangle_key(key):
-    """Wrapper for dogpile's sha1_mangle_key.
-
-    Taken from oslo_cache.core._sha1_mangle_key
-
-    dogpile's sha1_mangle_key function expects an encoded string, so we
-    should take steps to properly handle multiple inputs before passing
-    the key through.
-    """
-    try:
-        key = key.encode('utf-8', errors='xmlcharrefreplace')
-    except (UnicodeError, AttributeError):  # nosec
-        # NOTE(stevemar): if encoding fails just continue anyway.
-        pass
-    return dogpile_util.sha1_mangle_key(key)
-
-
 class LockTimeout(exception.UnexpectedError):
     debug_message_format = _('Lock Timeout occurred for key, %(target)s')
 
@@ -91,14 +76,7 @@ class KeyValueStore(object):
 
     This manager also supports the concept of locking a given key resource to
     allow for a guaranteed atomic transaction to the backend.
-
-    Deprecated as of Newton.
     """
-
-    @versionutils.deprecated(
-        versionutils.deprecated.NEWTON,
-        what='keystone key-value-store common code',
-        remove_in=+2)
     def __init__(self, kvs_region):
         self.locking = True
         self._lock_timeout = 0
@@ -118,8 +96,9 @@ class KeyValueStore(object):
                         this instantiation
         :param region_config_args: key-word args passed to the dogpile.cache
                                    backend for configuration
+        :return:
         """
-        if self.is_configured:
+        if 'backend' in self._region.__dict__:
             # NOTE(morganfainberg): It is a bad idea to reconfigure a backend,
             # there are a lot of pitfalls and potential memory leaks that could
             # occur.  By far the best approach is to re-create the KVS object
@@ -134,17 +113,13 @@ class KeyValueStore(object):
         self._set_key_mangler(key_mangler)
         self._apply_region_proxy(proxy_list)
 
-    @property
-    def is_configured(self):
-        return 'backend' in self._region.__dict__
-
     def _apply_region_proxy(self, proxy_list):
         if isinstance(proxy_list, list):
             proxies = []
 
             for item in proxy_list:
                 if isinstance(item, str):
-                    LOG.debug('Importing class %s as KVS proxy.', item)
+                    LOG.debug(_('Importing class %s as KVS proxy.'), item)
                     pxy = importutils.import_class(item)
                 else:
                     pxy = item
@@ -152,16 +127,12 @@ class KeyValueStore(object):
                 if issubclass(pxy, proxy.ProxyBackend):
                     proxies.append(pxy)
                 else:
-                    pxy_cls_name = reflection.get_class_name(
-                        pxy, fully_qualified=False)
-                    LOG.warning(_LW('%s is not a dogpile.proxy.ProxyBackend'),
-                                pxy_cls_name)
+                    LOG.warning(_('%s is not a dogpile.proxy.ProxyBackend'),
+                                pxy.__name__)
 
             for proxy_cls in reversed(proxies):
-                proxy_cls_name = reflection.get_class_name(
-                    proxy_cls, fully_qualified=False)
-                LOG.info(_LI('Adding proxy \'%(proxy)s\' to KVS %(name)s.'),
-                         {'proxy': proxy_cls_name,
+                LOG.info(_('Adding proxy \'%(proxy)s\' to KVS %(name)s.'),
+                         {'proxy': proxy_cls.__name__,
                           'name': self._region.name})
                 self._region.wrap(proxy_cls)
 
@@ -172,24 +143,24 @@ class KeyValueStore(object):
                                             self._region.name)
 
     def _set_keymangler_on_backend(self, key_mangler):
-        try:
-            self._region.backend.key_mangler = key_mangler
-        except Exception as e:
-            # NOTE(morganfainberg): The setting of the key_mangler on the
-            # backend is used to allow the backend to
-            # calculate a hashed key value as needed. Not all backends
-            # require the ability to calculate hashed keys. If the
-            # backend does not support/require this feature log a
-            # debug line and move on otherwise raise the proper exception.
-            # Support of the feature is implied by the existence of the
-            # 'raw_no_expiry_keys' attribute.
-            if not hasattr(self._region.backend, 'raw_no_expiry_keys'):
-                LOG.debug(('Non-expiring keys not supported/required by '
-                           '%(region)s backend; unable to set '
-                           'key_mangler for backend: %(err)s'),
-                          {'region': self._region.name, 'err': e})
-            else:
-                raise
+            try:
+                self._region.backend.key_mangler = key_mangler
+            except Exception as e:
+                # NOTE(morganfainberg): The setting of the key_mangler on the
+                # backend is used to allow the backend to
+                # calculate a hashed key value as needed. Not all backends
+                # require the ability to calculate hashed keys. If the
+                # backend does not support/require this feature log a
+                # debug line and move on otherwise raise the proper exception.
+                # Support of the feature is implied by the existence of the
+                # 'raw_no_expiry_keys' attribute.
+                if not hasattr(self._region.backend, 'raw_no_expiry_keys'):
+                    LOG.debug(_('Non-expiring keys not supported/required by '
+                                '%(region)s backend; unable to set '
+                                'key_mangler for backend: %(err)s'),
+                              {'region': self._region.name, 'err': e})
+                else:
+                    raise
 
     def _set_key_mangler(self, key_mangler):
         # Set the key_mangler that is appropriate for the given region being
@@ -210,7 +181,7 @@ class KeyValueStore(object):
 
         if CONF.kvs.enable_key_mangler:
             if key_mangler is not None:
-                msg = _LI('Using %(func)s as KVS region %(name)s key_mangler')
+                msg = _('Using %(func)s as KVS region %(name)s key_mangler')
                 if callable(key_mangler):
                     self._region.key_mangler = key_mangler
                     LOG.info(msg, {'func': key_mangler.__name__,
@@ -222,17 +193,17 @@ class KeyValueStore(object):
                     raise exception.ValidationError(
                         _('`key_mangler` option must be a function reference'))
             else:
-                msg = _LI('Using default keystone.common.kvs.sha1_mangle_key '
-                          'as KVS region %s key_mangler')
-                LOG.info(msg, self._region.name)
-                # NOTE(morganfainberg): Use 'default' keymangler to ensure
-                # that unless explicitly changed, we mangle keys.  This helps
-                # to limit unintended cases of exceeding cache-key in backends
-                # such as memcache.
-                self._region.key_mangler = sha1_mangle_key
+                LOG.info(_('Using default dogpile sha1_mangle_key as KVS '
+                           'region %s key_mangler'), self._region.name)
+                # NOTE(morganfainberg): Sane 'default' keymangler is the
+                # dogpile sha1_mangle_key function.  This ensures that unless
+                # explicitly changed, we mangle keys.  This helps to limit
+                # unintended cases of exceeding cache-key in backends such
+                # as memcache.
+                self._region.key_mangler = dogpile_util.sha1_mangle_key
             self._set_keymangler_on_backend(self._region.key_mangler)
         else:
-            LOG.info(_LI('KVS region %s key_mangler disabled.'),
+            LOG.info(_('KVS region %s key_mangler disabled.'),
                      self._region.name)
             self._set_keymangler_on_backend(None)
 
@@ -257,11 +228,11 @@ class KeyValueStore(object):
         if config_args['lock_timeout'] > 0:
             config_args['lock_timeout'] += LOCK_WINDOW
 
-        for argument, value in config_args.items():
+        for argument, value in six.iteritems(config_args):
             arg_key = '.'.join([prefix, 'arguments', argument])
             conf_dict[arg_key] = value
 
-        LOG.debug('KVS region configuration for %(name)s: %(config)r',
+        LOG.debug(_('KVS region configuration for %(name)s: %(config)r'),
                   {'name': self._region.name, 'config': conf_dict})
         self._region.configure_from_config(conf_dict, '%s.' % prefix)
 
@@ -277,7 +248,6 @@ class KeyValueStore(object):
 
     class _LockWrapper(object):
         """weakref-capable threading.Lock wrapper."""
-
         def __init__(self, lock_timeout):
             self.lock = threading.Lock()
             self.lock_timeout = lock_timeout
@@ -361,14 +331,12 @@ class KeyValueStore(object):
         timeout.
         """
         self._assert_configured()
-        return KeyValueStoreLock(self._mutex(key), key, self.locking,
-                                 self._lock_timeout)
+        return KeyValueStoreLock(self._mutex(key), key, self.locking)
 
     @contextlib.contextmanager
     def _action_with_lock(self, key, lock=None):
-        """Wrapper context manager.
-
-        Validates and handles the lock and lock timeout if passed in.
+        """Wrapper context manager to validate and handle the lock and lock
+        timeout if passed in.
         """
         if not isinstance(lock, KeyValueStoreLock):
             # NOTE(morganfainberg): Locking only matters if a lock is passed in
@@ -390,25 +358,22 @@ class KeyValueStore(object):
 
 
 class KeyValueStoreLock(object):
-    """Basic KeyValueStoreLock context manager.
+    """Basic KeyValueStoreLock context manager that hooks into the
+    dogpile.cache backend mutex allowing for distributed locking on resources.
 
-    Hooks into the dogpile.cache backend mutex allowing for distributed locking
-    on resources. This is only a write lock, and will not prevent reads from
-    occurring.
+    This is only a write lock, and will not prevent reads from occurring.
     """
-
-    def __init__(self, mutex, key, locking_enabled=True, lock_timeout=0):
+    def __init__(self, mutex, key, locking_enabled=True):
         self.mutex = mutex
         self.key = key
         self.enabled = locking_enabled
-        self.lock_timeout = lock_timeout
         self.active = False
         self.acquire_time = 0
 
     def acquire(self):
         if self.enabled:
             self.mutex.acquire()
-            LOG.debug('KVS lock acquired for: %s', self.key)
+            LOG.debug(_('KVS lock acquired for: %s'), self.key)
         self.active = True
         self.acquire_time = time.time()
         return self
@@ -417,30 +382,27 @@ class KeyValueStoreLock(object):
 
     @property
     def expired(self):
-        if self.lock_timeout:
-            calculated = time.time() - self.acquire_time + LOCK_WINDOW
-            return calculated > self.lock_timeout
-        else:
+        if self.mutex.lock_timeout == 0:
             return False
+        else:
+            calculated = time.time() - self.acquire_time + LOCK_WINDOW
+            return calculated > self.mutex.lock_timeout
 
     def release(self):
         if self.enabled:
             self.mutex.release()
             if not self.expired:
-                LOG.debug('KVS lock released for: %s', self.key)
+                LOG.debug(_('KVS lock released for: %s'), self.key)
             else:
-                LOG.warning(_LW('KVS lock released (timeout reached) for: %s'),
+                LOG.warning(_('KVS lock released (timeout reached) for: %s'),
                             self.key)
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        """Release the lock."""
         self.release()
 
 
 def get_key_value_store(name, kvs_region=None):
-    """Retrieve key value store.
-
-    Instantiate a new :class:`.KeyValueStore` or return a previous
+    """Instantiate a new :class:`.KeyValueStore` or return a previous
     instantiation that has the same name.
     """
     global KEY_VALUE_STORE_REGISTRY
