@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 Red Hat, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -27,6 +25,9 @@ def _sd_notify(msg):
     sysd = os.getenv('NOTIFY_SOCKET')
     if sysd:
         sock = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM)
+        if sysd.startswith('@'):
+            # abstract namespace socket
+            sysd = '\0%s' % sysd[1:]
         sock.connect(sysd)
         sock.sendall(msg)
         sock.close()
