@@ -1,3 +1,5 @@
+# flake8: noqa
+
 # Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,7 +14,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from keystone.contrib.ec2 import controllers  # noqa
-from keystone.contrib.ec2.core import *  # noqa
-from keystone.contrib.ec2.routers import Ec2Extension  # noqa
-from keystone.contrib.ec2.routers import Ec2ExtensionV3  # noqa
+from keystone.contrib.ec2 import controllers
+from keystone.contrib.ec2.core import *
+from keystone.contrib.ec2.routers import Ec2Extension
+from keystone.contrib.ec2.routers import Ec2ExtensionV3
