@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,6 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import six
+
 from keystone.catalog.backends import sql
 from keystone.catalog import core as catalog_core
 from keystone.common import dependency
@@ -26,14 +26,14 @@ CONF = config.CONF
 @dependency.requires('endpoint_filter_api')
 class EndpointFilterCatalog(sql.Catalog):
     def get_v3_catalog(self, user_id, project_id, metadata=None):
-        d = dict(CONF.iteritems())
+        d = dict(six.iteritems(CONF))
         d.update({'tenant_id': project_id, 'user_id': user_id})
 
         services = {}
 
         refs = self.endpoint_filter_api.list_endpoints_for_project(project_id)
 
-        if (len(refs) == 0 and
+        if (not refs and
                 CONF.endpoint_filter.return_all_endpoints_if_no_filter):
             return super(EndpointFilterCatalog, self).get_v3_catalog(
                 user_id, project_id, metadata=metadata)
@@ -41,12 +41,17 @@ class EndpointFilterCatalog(sql.Catalog):
         for entry in refs:
             try:
                 endpoint = self.get_endpoint(entry.endpoint_id)
+                if not endpoint['enabled']:
+                    # Skip disabled endpoints.
+                    continue
                 service_id = endpoint['service_id']
                 services.setdefault(
                     service_id,
                     self.get_service(service_id))
                 service = services[service_id]
                 del endpoint['service_id']
+                del endpoint['enabled']
+                del endpoint['legacy_endpoint_id']
                 endpoint['url'] = catalog_core.format_url(
                     endpoint['url'], d)
                 # populate filtered endpoints
@@ -61,7 +66,7 @@ class EndpointFilterCatalog(sql.Catalog):
 
         # format catalog
         catalog = []
-        for service_id, service in services.iteritems():
+        for service_id, service in six.iteritems(services):
             formatted_service = {}
             formatted_service['id'] = service['id']
             formatted_service['type'] = service['type']
