@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 Red Hat, Inc
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -17,13 +15,33 @@
 import copy
 import uuid
 
-from keystone.common import logging
+from keystone.common import extension
 from keystone.common import wsgi
 from keystone import exception
 from keystone import identity
+from keystone.openstack.common import log
 
 
-LOG = logging.getLogger(__name__)
+LOG = log.getLogger(__name__)
+
+
+extension.register_public_extension(
+    'OS-KSCRUD', {
+        'name': 'OpenStack Keystone User CRUD',
+        'namespace': 'http://docs.openstack.org/identity/api/ext/'
+                     'OS-KSCRUD/v1.0',
+        'alias': 'OS-KSCRUD',
+        'updated': '2013-07-07T12:00:0-00:00',
+        'description': 'OpenStack extensions to Keystone v2.0 API '
+                       'enabling User Operations.',
+        'links': [
+            {
+                'rel': 'describedby',
+                # TODO(ayoung): needs a description
+                'type': 'text/html',
+                'href': 'https://github.com/openstack/identity-api',
+            }
+        ]})
 
 
 class UserController(identity.controllers.User):
@@ -31,8 +49,7 @@ class UserController(identity.controllers.User):
         token_id = context.get('token_id')
         original_password = user.get('original_password')
 
-        token_ref = self.token_api.get_token(context=context,
-                                             token_id=token_id)
+        token_ref = self.token_api.get_token(token_id)
         user_id_from_token = token_ref['user']['id']
 
         if user_id_from_token != user_id:
@@ -43,9 +60,9 @@ class UserController(identity.controllers.User):
 
         try:
             user_ref = self.identity_api.authenticate(
-                context=context,
+                context,
                 user_id=user_id_from_token,
-                password=original_password)[0]
+                password=original_password)
             if not user_ref.get('enabled', True):
                 # NOTE(dolph): why can't you set a disabled user's password?
                 raise exception.Unauthorized('User is disabled')
@@ -63,18 +80,13 @@ class UserController(identity.controllers.User):
         token_id = uuid.uuid4().hex
         new_token_ref = copy.copy(token_ref)
         new_token_ref['id'] = token_id
-        self.token_api.create_token(context=context, token_id=token_id,
-                                    data=new_token_ref)
-        logging.debug('TOKEN_REF %s', new_token_ref)
+        self.token_api.create_token(token_id, new_token_ref)
+        LOG.debug('TOKEN_REF %s', new_token_ref)
         return {'access': {'token': new_token_ref}}
 
 
 class CrudExtension(wsgi.ExtensionRouter):
-    """
-
-    Provides a subset of CRUD operations for internal data types.
-
-    """
+    """Provides a subset of CRUD operations for internal data types."""
 
     def add_routes(self, mapper):
         user_controller = UserController()
