@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2012 OpenStack LLC
+# Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -15,36 +13,39 @@
 # under the License.
 
 from keystone.common import controller
+from keystone.common import dependency
 
 
+@dependency.requires('policy_api')
 class PolicyV3(controller.V3Controller):
     collection_name = 'policies'
     member_name = 'policy'
 
-    @controller.protected
+    @controller.protected()
     def create_policy(self, context, policy):
         ref = self._assign_unique_id(self._normalize_dict(policy))
         self._require_attribute(ref, 'blob')
         self._require_attribute(ref, 'type')
 
-        ref = self.policy_api.create_policy(context, ref['id'], ref)
+        ref = self.policy_api.create_policy(ref['id'], ref)
         return PolicyV3.wrap_member(context, ref)
 
     @controller.filterprotected('type')
     def list_policies(self, context, filters):
-        refs = self.policy_api.list_policies(context)
-        return PolicyV3.wrap_collection(context, refs, filters)
+        hints = PolicyV3.build_driver_hints(context, filters)
+        refs = self.policy_api.list_policies(hints=hints)
+        return PolicyV3.wrap_collection(context, refs, hints=hints)
 
-    @controller.protected
+    @controller.protected()
     def get_policy(self, context, policy_id):
-        ref = self.policy_api.get_policy(context, policy_id)
+        ref = self.policy_api.get_policy(policy_id)
         return PolicyV3.wrap_member(context, ref)
 
-    @controller.protected
+    @controller.protected()
     def update_policy(self, context, policy_id, policy):
-        ref = self.policy_api.update_policy(context, policy_id, policy)
+        ref = self.policy_api.update_policy(policy_id, policy)
         return PolicyV3.wrap_member(context, ref)
 
-    @controller.protected
+    @controller.protected()
     def delete_policy(self, context, policy_id):
-        return self.policy_api.delete_policy(context, policy_id)
+        return self.policy_api.delete_policy(policy_id)
