@@ -15,8 +15,11 @@
 import copy
 import uuid
 
-# NOTE(morganfainberg): import endpoint filter to populate the SQL model
-from keystone.contrib import endpoint_filter  # flake8: noqa
+from keystone.common import sql
+from keystone.common.sql import migration_helpers
+from keystone import contrib
+from keystone.openstack.common.db.sqlalchemy import migration
+from keystone.openstack.common import importutils
 from keystone.tests import test_v3
 
 
@@ -25,6 +28,14 @@ class TestExtensionCase(test_v3.RestfulTestCase):
     EXTENSION_NAME = 'endpoint_filter'
     EXTENSION_TO_ADD = 'endpoint_filter_extension'
 
+    def setup_database(self):
+        super(TestExtensionCase, self).setup_database()
+        package_name = '.'.join((contrib.__name__, self.EXTENSION_NAME))
+        package = importutils.import_module(package_name)
+        abs_path = migration_helpers.find_migrate_repo(package)
+        migration.db_version_control(sql.get_engine(), abs_path)
+        migration.db_sync(sql.get_engine(), abs_path)
+
     def config_overrides(self):
         super(TestExtensionCase, self).config_overrides()
         self.config_fixture.config(
@@ -41,9 +52,12 @@ class TestExtensionCase(test_v3.RestfulTestCase):
                 'endpoint_id': self.endpoint_id})
 
 
-class EndpointFilterCRUDTestCase(TestExtensionCase):
+class AssociateEndpointProjectFilterCRUDTestCase(TestExtensionCase):
+    """Test OS-EP-FILTER endpoint to project associations extension."""
 
-    def test_create_endpoint_project_association(self):
+    # endpoint-project associations crud tests
+    # PUT
+    def test_create_endpoint_project_assoc(self):
         """PUT /OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}
 
         Valid endpoint and project id test case.
@@ -53,7 +67,7 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                  body='',
                  expected_status=204)
 
-    def test_create_endpoint_project_association_with_invalid_project(self):
+    def test_create_endpoint_project_assoc_noproj(self):
         """PUT OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}
 
         Invalid project id test case.
@@ -66,7 +80,7 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                  body='',
                  expected_status=404)
 
-    def test_create_endpoint_project_association_with_invalid_endpoint(self):
+    def test_create_endpoint_project_assoc_noendp(self):
         """PUT /OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}
 
         Invalid endpoint id test case.
@@ -79,7 +93,7 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                  body='',
                  expected_status=404)
 
-    def test_create_endpoint_project_association_with_unexpected_body(self):
+    def test_create_endpoint_project_assoc_unexpected_body(self):
         """PUT /OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}
 
         Unexpected body in request. The body should be ignored.
@@ -89,7 +103,8 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                  body={'project_id': self.default_domain_project_id},
                  expected_status=204)
 
-    def test_check_endpoint_project_association(self):
+    # HEAD
+    def test_check_endpoint_project_assoc(self):
         """HEAD /OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}
 
         Valid project and endpoint id test case.
@@ -104,7 +119,7 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                       'endpoint_id': self.endpoint_id},
                   expected_status=204)
 
-    def test_check_endpoint_project_association_with_invalid_project(self):
+    def test_check_endpoint_project_assoc_noproj(self):
         """HEAD /OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}
 
         Invalid project id test case.
@@ -118,7 +133,7 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                   body='',
                   expected_status=404)
 
-    def test_check_endpoint_project_association_with_invalid_endpoint(self):
+    def test_check_endpoint_project_assoc_noendp(self):
         """HEAD /OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}
 
         Invalid endpoint id test case.
@@ -132,48 +147,26 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                   body='',
                   expected_status=404)
 
-    def test_list_endpoints_associated_with_valid_project(self):
-        """GET /OS-EP-FILTER/projects/{project_id}/endpoints
-
-        Valid project and endpoint id test case.
-
-        """
+    # GET
+    def test_get_endpoint_project_assoc(self):
+        """GET /OS-EP-FILTER/projects/{project_id}/endpoints success."""
         self.put(self.default_request_url)
-        resource_url = '/OS-EP-FILTER/projects/%(project_id)s/endpoints' % {
-                       'project_id': self.default_domain_project_id}
-        r = self.get(resource_url)
-        self.assertValidEndpointListResponse(r, self.endpoint,
-                                             resource_url=resource_url)
+        r = self.get('/OS-EP-FILTER/projects/%(project_id)s/endpoints' % {
+                     'project_id': self.default_domain_project_id})
+        self.assertValidEndpointListResponse(r, self.endpoint)
 
-    def test_list_endpoints_associated_with_invalid_project(self):
-        """GET /OS-EP-FILTER/projects/{project_id}/endpoints
-
-        Invalid project id test case.
-
-        """
+    def test_get_endpoint_project_assoc_noproj(self):
+        """GET /OS-EP-FILTER/projects/{project_id}/endpoints no project."""
         self.put(self.default_request_url)
         self.get('/OS-EP-FILTER/projects/%(project_id)s/endpoints' % {
                  'project_id': uuid.uuid4().hex},
                  body='',
                  expected_status=404)
 
-    def test_list_projects_associated_with_endpoint(self):
-        """GET /OS-EP-FILTER/endpoints/{endpoint_id}/projects
+    def test_list_projects_for_endpoint_default(self):
+        """GET /OS-EP-FILTER/endpoints/{endpoint_id}/projects success
 
-        Valid endpoint-project association test case.
-
-        """
-        self.put(self.default_request_url)
-        resource_url = '/OS-EP-FILTER/endpoints/%(endpoint_id)s/projects' % {
-                       'endpoint_id': self.endpoint_id}
-        r = self.get(resource_url)
-        self.assertValidProjectListResponse(r, self.default_domain_project,
-                                            resource_url=resource_url)
-
-    def test_list_projects_with_no_endpoint_project_association(self):
-        """GET /OS-EP-FILTER/endpoints/{endpoint_id}/projects
-
-        Valid endpoint id but no endpoint-project associations test case.
+        Don't associate project and endpoint, then get empty list.
 
         """
         r = self.get('/OS-EP-FILTER/endpoints/%(endpoint_id)s/projects' %
@@ -181,7 +174,7 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                      expected_status=200)
         self.assertValidProjectListResponse(r, expected_length=0)
 
-    def test_list_projects_associated_with_invalid_endpoint(self):
+    def test_list_projects_for_endpoint_noendpoint(self):
         """GET /OS-EP-FILTER/endpoints/{endpoint_id}/projects
 
         Invalid endpoint id test case.
@@ -191,7 +184,20 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                  {'endpoint_id': uuid.uuid4().hex},
                  expected_status=404)
 
-    def test_remove_endpoint_project_association(self):
+    def test_list_projects_for_endpoint_assoc(self):
+        """GET /OS-EP-FILTER/endpoints/{endpoint_id}/projects success
+
+        Associate default project and endpoint, then get it.
+
+        """
+        self.put(self.default_request_url)
+        r = self.get('/OS-EP-FILTER/endpoints/%(endpoint_id)s/projects' %
+                     {'endpoint_id': self.endpoint_id},
+                     expected_status=200)
+        self.assertValidProjectListResponse(r, self.default_domain_project)
+
+    # DELETE
+    def test_remove_endpoint_project_assoc(self):
         """DELETE /OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}
 
         Valid project id and endpoint id test case.
@@ -204,7 +210,7 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                         'endpoint_id': self.endpoint_id},
                     expected_status=204)
 
-    def test_remove_endpoint_project_association_with_invalid_project(self):
+    def test_remove_endpoint_project_assoc_noproj(self):
         """DELETE /OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}
 
         Invalid project id test case.
@@ -218,7 +224,7 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                     body='',
                     expected_status=404)
 
-    def test_remove_endpoint_project_association_with_invalid_endpoint(self):
+    def test_remove_endpoint_project_assoc_noendp(self):
         """DELETE /OS-EP-FILTER/projects/{project_id}/endpoints/{endpoint_id}
 
         Invalid endpoint id test case.
@@ -232,38 +238,12 @@ class EndpointFilterCRUDTestCase(TestExtensionCase):
                     body='',
                     expected_status=404)
 
-    def test_endpoint_project_association_cleanup_when_project_deleted(self):
-        self.put(self.default_request_url)
-        association_url = '/OS-EP-FILTER/endpoints/%(endpoint_id)s/projects' % {
-            'endpoint_id': self.endpoint_id}
-        r = self.get(association_url, expected_status=200)
-        self.assertValidProjectListResponse(r, expected_length=1)
 
-        self.delete('/projects/%(project_id)s' % {
-            'project_id': self.default_domain_project_id})
+class AssociateProjectEndpointFilterTokenRequestTestCase(TestExtensionCase):
+    """Test OS-EP-FILTER catalog filtering extension."""
 
-        r = self.get(association_url, expected_status=200)
-        self.assertValidProjectListResponse(r, expected_length=0)
-
-    def test_endpoint_project_association_cleanup_when_endpoint_deleted(self):
-        self.put(self.default_request_url)
-        association_url = '/OS-EP-FILTER/projects/%(project_id)s/endpoints' % {
-            'project_id': self.default_domain_project_id}
-        r = self.get(association_url, expected_status=200)
-        self.assertValidEndpointListResponse(r, expected_length=1)
-
-        self.delete('/endpoints/%(endpoint_id)s' % {
-            'endpoint_id': self.endpoint_id})
-
-        r = self.get(association_url, expected_status=200)
-        self.assertValidEndpointListResponse(r, expected_length=0)
-
-
-class EndpointFilterTokenRequestTestCase(TestExtensionCase):
-
-    def test_project_scoped_token_using_endpoint_filter(self):
-        """Verify endpoints from project scoped token filtered.""" 
-        # create a project to work with
+    def test_default_project_id_scoped_token_with_user_id_ep_filter(self):
+        # create a second project to work with
         ref = self.new_project_ref(domain_id=self.domain_id)
         r = self.post('/projects', body={'project': ref})
         project = self.assertValidProjectResponse(r, ref)
@@ -302,8 +282,9 @@ class EndpointFilterTokenRequestTestCase(TestExtensionCase):
             ep_filter_assoc=1)
         self.assertEqual(r.result['token']['project']['id'], project['id'])
 
-    def test_default_scoped_token_using_endpoint_filter(self):
-        """Verify endpoints from default scoped token filtered."""
+    def test_implicit_project_id_scoped_token_with_user_id_ep_filter(self):
+        # attempt to authenticate without requesting a project
+
         # add one endpoint to default project
         self.put('/OS-EP-FILTER/projects/%(project_id)s'
                  '/endpoints/%(endpoint_id)s' % {
@@ -325,14 +306,8 @@ class EndpointFilterTokenRequestTestCase(TestExtensionCase):
         self.assertEqual(r.result['token']['project']['id'],
                          self.project['id'])
 
-    def test_project_scoped_token_with_no_catalog_using_endpoint_filter(self): 
-        """Verify endpoint filter when project scoped token returns no catalog.
-
-        Test that the project scoped token response is valid for a given
-        endpoint-project association when no service catalog is returned.
-
-        """
-        # create a project to work with
+    def test_default_project_id_scoped_token_ep_filter_no_catalog(self):
+        # create a second project to work with
         ref = self.new_project_ref(domain_id=self.domain_id)
         r = self.post('/projects', body={'project': ref})
         project = self.assertValidProjectResponse(r, ref)
@@ -371,13 +346,9 @@ class EndpointFilterTokenRequestTestCase(TestExtensionCase):
             ep_filter_assoc=1)
         self.assertEqual(r.result['token']['project']['id'], project['id'])
 
-    def test_default_scoped_token_with_no_catalog_using_endpoint_filter(self):
-        """Verify endpoint filter when default scoped token returns no catalog.
+    def test_implicit_project_id_scoped_token_ep_filter_no_catalog(self):
+        # attempt to authenticate without requesting a project
 
-        Test that the default project scoped token response is valid for a
-        given endpoint-project association when no service catalog is returned.
-
-        """
         # add one endpoint to default project
         self.put('/OS-EP-FILTER/projects/%(project_id)s'
                  '/endpoints/%(endpoint_id)s' % {
@@ -399,14 +370,8 @@ class EndpointFilterTokenRequestTestCase(TestExtensionCase):
         self.assertEqual(r.result['token']['project']['id'],
                          self.project['id'])
 
-    def test_project_scoped_token_with_no_endpoint_project_association(self):
-        """Verify endpoint filter when no endpoint-project association.
-
-        Test that the project scoped token response is valid when there are
-        no endpoint-project associations defined.
-
-        """
-        # create a project to work with
+    def test_default_project_id_scoped_token_ep_filter_full_catalog(self):
+        # create a second project to work with
         ref = self.new_project_ref(domain_id=self.domain_id)
         r = self.post('/projects', body={'project': ref})
         project = self.assertValidProjectResponse(r, ref)
@@ -436,13 +401,9 @@ class EndpointFilterTokenRequestTestCase(TestExtensionCase):
             endpoint_filter=True)
         self.assertEqual(r.result['token']['project']['id'], project['id'])
 
-    def test_default_scoped_token_with_no_endpoint_project_association(self):
-        """Verify endpoint filter when no endpoint-project association.
+    def test_implicit_project_id_scoped_token_ep_filter_full_catalog(self):
+        # attempt to authenticate without requesting a project
 
-        Test that the default project scoped token response is valid when
-        there are no endpoint-project associations defined.
-        
-        """
         auth_data = self.build_authentication_request(
             user_id=self.user['id'],
             password=self.user['password'],
@@ -455,8 +416,9 @@ class EndpointFilterTokenRequestTestCase(TestExtensionCase):
         self.assertEqual(r.result['token']['project']['id'],
                          self.project['id'])
 
-    def test_invalid_endpoint_project_association(self):
-        """Verify an invalid endpoint-project association is handled."""
+    def test_implicit_project_id_scoped_token_handling_bad_reference(self):
+        # handling the case with an endpoint that is not associate with
+
         # add first endpoint to default project
         self.put('/OS-EP-FILTER/projects/%(project_id)s'
                  '/endpoints/%(endpoint_id)s' % {
@@ -500,7 +462,8 @@ class EndpointFilterTokenRequestTestCase(TestExtensionCase):
                          self.project['id'])
 
     def test_disabled_endpoint(self):
-        """Test that a disabled endpoint is handled."""
+        """The catalog contains only enabled endpoints."""
+
         # Add an enabled endpoint to the default project
         self.put('/OS-EP-FILTER/projects/%(project_id)s'
                  '/endpoints/%(endpoint_id)s' % {
