@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Metacloud
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -74,15 +72,26 @@ class TestProxyValue(object):
 
 
 class CacheRegionTest(tests.TestCase):
-    def __init__(self, *args, **kwargs):
-        super(CacheRegionTest, self).__init__(*args, **kwargs)
-        self.region = None
 
     def setUp(self):
         super(CacheRegionTest, self).setUp()
         self.region = cache.make_region()
         cache.configure_cache_region(self.region)
         self.region.wrap(TestProxy)
+        self.test_value = TestProxyValue('Decorator Test')
+
+    def _add_test_caching_option(self):
+        self.config_fixture.register_opt(
+            config.config.cfg.BoolOpt('caching', default=True), group='cache')
+
+    def _get_cacheable_function(self):
+        SHOULD_CACHE_FN = cache.should_cache_fn('cache')
+
+        @self.region.cache_on_arguments(should_cache_fn=SHOULD_CACHE_FN)
+        def cacheable_function(value):
+            return value
+
+        return cacheable_function
 
     def test_region_built_with_proxy_direct_cache_test(self):
         # Verify cache regions are properly built with proxies.
@@ -96,63 +105,87 @@ class CacheRegionTest(tests.TestCase):
         cache.configure_cache_region(self.region)
         cache.configure_cache_region(self.region)
 
-    def test_should_cache_fn(self):
-        # Verify should_cache_fn generates a sane function for subsystem
-        # toggle.
-        SHOULD_CACHE = cache.should_cache_fn('cache')
-        test_value = TestProxyValue('Decorator Test')
+    def test_should_cache_fn_global_cache_enabled(self):
+        # Verify should_cache_fn generates a sane function for subsystem and
+        # functions as expected with caching globally enabled.
+        cacheable_function = self._get_cacheable_function()
 
-        @self.region.cache_on_arguments(should_cache_fn=SHOULD_CACHE)
-        def cacheable_function(value):
-            return value
-
-        setattr(CONF.cache, 'caching', False)
-        cacheable_function(test_value)
-        cached_value = cacheable_function(test_value)
-        self.assertFalse(cached_value.cached)
-
-        setattr(CONF.cache, 'caching', True)
-        cacheable_function(test_value)
-        cached_value = cacheable_function(test_value)
+        self.config_fixture.config(group='cache', enabled=True)
+        cacheable_function(self.test_value)
+        cached_value = cacheable_function(self.test_value)
         self.assertTrue(cached_value.cached)
 
-    def test_should_cache_fn_global(self):
-        # Verify should_cache_fn generates a sane function for global
-        # toggle.
-        SHOULD_CACHE = cache.should_cache_fn('cache')
-        test_value = TestProxyValue('Decorator Test')
+    def test_should_cache_fn_global_cache_disabled(self):
+        # Verify should_cache_fn generates a sane function for subsystem and
+        # functions as expected with caching globally disabled.
+        cacheable_function = self._get_cacheable_function()
 
-        @self.region.cache_on_arguments(should_cache_fn=SHOULD_CACHE)
-        def cacheable_function(value):
-            return value
-
-        setattr(CONF.cache, 'enabled', False)
-        cacheable_function(test_value)
-        cached_value = cacheable_function(test_value)
+        self.config_fixture.config(group='cache', enabled=False)
+        cacheable_function(self.test_value)
+        cached_value = cacheable_function(self.test_value)
         self.assertFalse(cached_value.cached)
 
-        setattr(CONF.cache, 'enabled', True)
-        cacheable_function(test_value)
-        cached_value = cacheable_function(test_value)
+    def test_should_cache_fn_global_cache_disabled_section_cache_enabled(self):
+        # Verify should_cache_fn generates a sane function for subsystem and
+        # functions as expected with caching globally disabled and the specific
+        # section caching enabled.
+        cacheable_function = self._get_cacheable_function()
+
+        self._add_test_caching_option()
+        self.config_fixture.config(group='cache', enabled=False)
+        self.config_fixture.config(group='cache', caching=True)
+
+        cacheable_function(self.test_value)
+        cached_value = cacheable_function(self.test_value)
+        self.assertFalse(cached_value.cached)
+
+    def test_should_cache_fn_global_cache_enabled_section_cache_disabled(self):
+        # Verify should_cache_fn generates a sane function for subsystem and
+        # functions as expected with caching globally enabled and the specific
+        # section caching disabled.
+        cacheable_function = self._get_cacheable_function()
+
+        self._add_test_caching_option()
+        self.config_fixture.config(group='cache', enabled=True)
+        self.config_fixture.config(group='cache', caching=False)
+
+        cacheable_function(self.test_value)
+        cached_value = cacheable_function(self.test_value)
+        self.assertFalse(cached_value.cached)
+
+    def test_should_cache_fn_global_cache_enabled_section_cache_enabled(self):
+        # Verify should_cache_fn generates a sane function for subsystem and
+        # functions as expected with caching globally enabled and the specific
+        # section caching enabled.
+        cacheable_function = self._get_cacheable_function()
+
+        self._add_test_caching_option()
+        self.config_fixture.config(group='cache', enabled=True)
+        self.config_fixture.config(group='cache', caching=True)
+
+        cacheable_function(self.test_value)
+        cached_value = cacheable_function(self.test_value)
         self.assertTrue(cached_value.cached)
 
     def test_cache_dictionary_config_builder(self):
         """Validate we build a sane dogpile.cache dictionary config."""
-        CONF.cache.config_prefix = 'test_prefix'
-        CONF.cache.backend = 'some_test_backend'
-        CONF.cache.expiration_time = 86400
-        CONF.cache.backend_argument = ['arg1:test', 'arg2:test:test',
-                                       'arg3.invalid']
+        self.config_fixture.config(group='cache',
+                                   config_prefix='test_prefix',
+                                   backend='some_test_backend',
+                                   expiration_time=86400,
+                                   backend_argument=['arg1:test',
+                                                     'arg2:test:test',
+                                                     'arg3.invalid'])
 
         config_dict = cache.build_cache_config()
-        self.assertEquals(
-            config_dict['test_prefix.backend'], CONF.cache.backend)
-        self.assertEquals(
-            config_dict['test_prefix.expiration_time'],
-            CONF.cache.expiration_time)
-        self.assertEquals(config_dict['test_prefix.arguments.arg1'], 'test')
-        self.assertEquals(config_dict['test_prefix.arguments.arg2'],
-                          'test:test')
+        self.assertEqual(
+            CONF.cache.backend, config_dict['test_prefix.backend'])
+        self.assertEqual(
+            CONF.cache.expiration_time,
+            config_dict['test_prefix.expiration_time'])
+        self.assertEqual('test', config_dict['test_prefix.arguments.arg1'])
+        self.assertEqual('test:test',
+                         config_dict['test_prefix.arguments.arg2'])
         self.assertFalse('test_prefix.arguments.arg3' in config_dict)
 
     def test_cache_debug_proxy(self):
@@ -161,20 +194,20 @@ class CacheRegionTest(tests.TestCase):
         multi_values = {'key1': 1, 'key2': 2, 'key3': 3}
 
         self.region.set(single_key, single_value)
-        self.assertEquals(single_value, self.region.get(single_key))
+        self.assertEqual(single_value, self.region.get(single_key))
 
         self.region.delete(single_key)
-        self.assertEquals(NO_VALUE, self.region.get(single_key))
+        self.assertEqual(NO_VALUE, self.region.get(single_key))
 
         self.region.set_multi(multi_values)
         cached_values = self.region.get_multi(multi_values.keys())
         for value in multi_values.values():
             self.assertIn(value, cached_values)
-        self.assertEquals(len(multi_values.values()), len(cached_values))
+        self.assertEqual(len(multi_values.values()), len(cached_values))
 
         self.region.delete_multi(multi_values.keys())
         for value in self.region.get_multi(multi_values.keys()):
-            self.assertEquals(NO_VALUE, value)
+            self.assertEqual(NO_VALUE, value)
 
     def test_configure_non_region_object_raises_error(self):
         self.assertRaises(exception.ValidationError,
@@ -183,29 +216,30 @@ class CacheRegionTest(tests.TestCase):
 
 
 class CacheNoopBackendTest(tests.TestCase):
-    def __init__(self, *args, **kwargs):
-        super(CacheNoopBackendTest, self).__init__(*args, **kwargs)
-        self.region = None
 
     def setUp(self):
         super(CacheNoopBackendTest, self).setUp()
         self.region = cache.make_region()
-        setattr(CONF.cache, 'backend', 'keystone.common.cache.noop')
         cache.configure_cache_region(self.region)
 
+    def config_overrides(self):
+        super(CacheNoopBackendTest, self).config_overrides()
+        self.config_fixture.config(group='cache',
+                                   backend='keystone.common.cache.noop')
+
     def test_noop_backend(self):
         single_value = 'Test Value'
         single_key = 'testkey'
         multi_values = {'key1': 1, 'key2': 2, 'key3': 3}
 
         self.region.set(single_key, single_value)
-        self.assertEquals(NO_VALUE, self.region.get(single_key))
+        self.assertEqual(NO_VALUE, self.region.get(single_key))
 
         self.region.set_multi(multi_values)
         cached_values = self.region.get_multi(multi_values.keys())
-        self.assertEquals(len(cached_values), len(multi_values.values()))
+        self.assertEqual(len(cached_values), len(multi_values.values()))
         for value in cached_values:
-            self.assertEquals(NO_VALUE, value)
+            self.assertEqual(NO_VALUE, value)
 
         # Delete should not raise exceptions
         self.region.delete(single_key)
