@@ -16,15 +16,16 @@ import gettext
 import socket
 import uuid
 
+from babel import localedata
 import mock
-from oslo import i18n
-import six
-from testtools import matchers
 import webob
 
 from keystone.common import environment
 from keystone.common import wsgi
 from keystone import exception
+from keystone.openstack.common.fixture import moxstubout
+from keystone.openstack.common import gettextutils
+from keystone.openstack.common.gettextutils import _
 from keystone.openstack.common import jsonutils
 from keystone import tests
 
@@ -34,21 +35,6 @@ class FakeApp(wsgi.Application):
         return {'a': 'b'}
 
 
-class FakeAttributeCheckerApp(wsgi.Application):
-    def index(self, context):
-        return context['query_string']
-
-    def assert_attribute(self, body, attr):
-        """Asserts that the given request has a certain attribute."""
-        ref = jsonutils.loads(body)
-        self._require_attribute(ref, attr)
-
-    def assert_attributes(self, body, attr):
-        """Asserts that the given request has a certain set attributes."""
-        ref = jsonutils.loads(body)
-        self._require_attributes(ref, attr)
-
-
 class BaseWSGITest(tests.TestCase):
     def setUp(self):
         self.app = FakeApp()
@@ -88,7 +74,7 @@ class ApplicationTest(BaseWSGITest):
 
     def test_render_response(self):
         data = {'attribute': 'value'}
-        body = b'{"attribute": "value"}'
+        body = '{"attribute": "value"}'
 
         resp = wsgi.render_response(body=data)
         self.assertEqual(resp.status, '200 OK')
@@ -102,48 +88,6 @@ class ApplicationTest(BaseWSGITest):
         self.assertEqual(resp.status, '501 Not Implemented')
         self.assertEqual(resp.status_int, 501)
 
-    def test_successful_require_attribute(self):
-        app = FakeAttributeCheckerApp()
-        req = self._make_request(url='/?1=2')
-        resp = req.get_response(app)
-        app.assert_attribute(resp.body, '1')
-
-    def test_require_attribute_fail_if_attribute_not_present(self):
-        app = FakeAttributeCheckerApp()
-        req = self._make_request(url='/?1=2')
-        resp = req.get_response(app)
-        self.assertRaises(exception.ValidationError,
-                          app.assert_attribute, resp.body, 'a')
-
-    def test_successful_require_multiple_attributes(self):
-        app = FakeAttributeCheckerApp()
-        req = self._make_request(url='/?a=1&b=2')
-        resp = req.get_response(app)
-        app.assert_attributes(resp.body, ['a', 'b'])
-
-    def test_attribute_missing_from_request(self):
-        app = FakeAttributeCheckerApp()
-        req = self._make_request(url='/?a=1&b=2')
-        resp = req.get_response(app)
-        ex = self.assertRaises(exception.ValidationError,
-                               app.assert_attributes,
-                               resp.body, ['a', 'missing_attribute'])
-        self.assertThat(six.text_type(ex),
-                        matchers.Contains('missing_attribute'))
-
-    def test_no_required_attributes_present(self):
-        app = FakeAttributeCheckerApp()
-        req = self._make_request(url='/')
-        resp = req.get_response(app)
-
-        ex = self.assertRaises(exception.ValidationError,
-                               app.assert_attributes, resp.body,
-                               ['missing_attribute1', 'missing_attribute2'])
-        self.assertThat(six.text_type(ex),
-                        matchers.Contains('missing_attribute1'))
-        self.assertThat(six.text_type(ex),
-                        matchers.Contains('missing_attribute2'))
-
     def test_render_response_custom_headers(self):
         resp = wsgi.render_response(headers=[('Custom-Header', 'Some-Value')])
         self.assertEqual(resp.headers.get('Custom-Header'), 'Some-Value')
@@ -153,9 +97,9 @@ class ApplicationTest(BaseWSGITest):
         resp = wsgi.render_response()
         self.assertEqual(resp.status, '204 No Content')
         self.assertEqual(resp.status_int, 204)
-        self.assertEqual(resp.body, b'')
+        self.assertEqual(resp.body, '')
         self.assertEqual(resp.headers.get('Content-Length'), '0')
-        self.assertIsNone(resp.headers.get('Content-Type'))
+        self.assertEqual(resp.headers.get('Content-Type'), None)
 
     def test_render_response_head_with_body(self):
         resp = wsgi.render_response({'id': uuid.uuid4().hex}, method='HEAD')
@@ -241,7 +185,7 @@ class MiddlewareTest(BaseWSGITest):
 
     def test_middleware_exception_error(self):
 
-        exception_str = b'EXCEPTIONERROR'
+        exception_str = 'EXCEPTIONERROR'
 
         class FakeMiddleware(wsgi.Middleware):
             def process_response(self, request, response):
@@ -273,101 +217,69 @@ class MiddlewareTest(BaseWSGITest):
 
 
 class LocalizedResponseTest(tests.TestCase):
+    def setUp(self):
+        super(LocalizedResponseTest, self).setUp()
+
+        gettextutils._AVAILABLE_LANGUAGES.clear()
+        self.addCleanup(gettextutils._AVAILABLE_LANGUAGES.clear)
+
+        fixture = self.useFixture(moxstubout.MoxStubout())
+        self.stubs = fixture.stubs
+
+    def _set_expected_languages(self, all_locales=[], avail_locales=None):
+        # Override localedata.locale_identifiers to return some locales.
+        def returns_some_locales(*args, **kwargs):
+            return all_locales
+
+        self.stubs.Set(localedata, 'locale_identifiers', returns_some_locales)
+
+        # Override gettext.find to return other than None for some languages.
+        def fake_gettext_find(lang_id, *args, **kwargs):
+            found_ret = '/keystone/%s/LC_MESSAGES/keystone.mo' % lang_id
+            if avail_locales is None:
+                # All locales are available.
+                return found_ret
+            languages = kwargs['languages']
+            if languages[0] in avail_locales:
+                return found_ret
+            return None
+
+        self.stubs.Set(gettext, 'find', fake_gettext_find)
+
     def test_request_match_default(self):
         # The default language if no Accept-Language is provided is None
         req = webob.Request.blank('/')
         self.assertIsNone(wsgi.best_match_language(req))
 
-    @mock.patch.object(i18n, 'get_available_languages')
-    def test_request_match_language_expected(self, mock_gal):
+    def test_request_match_language_expected(self):
         # If Accept-Language is a supported language, best_match_language()
         # returns it.
 
-        language = uuid.uuid4().hex
-        mock_gal.return_value = [language]
+        self._set_expected_languages(all_locales=['it'])
 
-        req = webob.Request.blank('/', headers={'Accept-Language': language})
-        self.assertEqual(wsgi.best_match_language(req), language)
+        req = webob.Request.blank('/', headers={'Accept-Language': 'it'})
+        self.assertEqual(wsgi.best_match_language(req), 'it')
 
-    @mock.patch.object(i18n, 'get_available_languages')
-    def test_request_match_language_unexpected(self, mock_gal):
+    def test_request_match_language_unexpected(self):
         # If Accept-Language is a language we do not support,
         # best_match_language() returns None.
 
-        supported_language = uuid.uuid4().hex
-        mock_gal.return_value = [supported_language]
+        self._set_expected_languages(all_locales=['it'])
 
-        request_language = uuid.uuid4().hex
-        req = webob.Request.blank(
-            '/', headers={'Accept-Language': request_language})
+        req = webob.Request.blank('/', headers={'Accept-Language': 'zh'})
         self.assertIsNone(wsgi.best_match_language(req))
 
-    def test_static_translated_string_is_lazy_translatable(self):
-        # Statically created message strings are an object that can get
-        # lazy-translated rather than a regular string.
-        self.assertNotEqual(type(exception.Unauthorized.message_format),
-                            six.text_type)
+    def test_static_translated_string_is_Message(self):
+        # Statically created message strings are Message objects so that they
+        # are lazy-translated.
+        self.assertIsInstance(exception.Unauthorized.message_format,
+                              gettextutils.Message)
 
-    @mock.patch.object(i18n, 'get_available_languages')
-    def test_get_localized_response(self, mock_gal):
-        # If the request has the Accept-Language set to a supported language
-        # and an exception is raised by the application that is translatable
-        # then the response will have the translated message.
-
-        language = uuid.uuid4().hex
-        mock_gal.return_value = [language]
-
-        # The arguments for the xlated message format have to match the args
-        # for the chosen exception (exception.NotFound)
-        xlated_msg_fmt = "Xlated NotFound, %(target)s."
-
-        # Fake out gettext.translation() to return a translator for our
-        # expected language and a passthrough translator for other langs.
-
-        def fake_translation(*args, **kwargs):
-            class IdentityTranslator(object):
-                def ugettext(self, msgid):
-                    return msgid
-
-                gettext = ugettext
-
-            class LangTranslator(object):
-                def ugettext(self, msgid):
-                    if msgid == exception.NotFound.message_format:
-                        return xlated_msg_fmt
-                    return msgid
-
-                gettext = ugettext
-
-            if language in kwargs.get('languages', []):
-                return LangTranslator()
-            return IdentityTranslator()
-
-        with mock.patch.object(gettext, 'translation',
-                               side_effect=fake_translation) as xlation_mock:
-            target = uuid.uuid4().hex
-
-            # Fake app raises NotFound exception to simulate Keystone raising.
-
-            class FakeApp(wsgi.Application):
-                def index(self, context):
-                    raise exception.NotFound(target=target)
-
-            # Make the request with Accept-Language on the app, expect an error
-            # response with the translated message.
-
-            req = webob.Request.blank('/')
-            args = {'action': 'index', 'controller': None}
-            req.environ['wsgiorg.routing_args'] = [None, args]
-            req.headers['Accept-Language'] = language
-            resp = req.get_response(FakeApp())
-
-            # Assert that the translated message appears in the response.
-
-            exp_msg = xlated_msg_fmt % dict(target=target)
-            self.assertThat(resp.json['error']['message'],
-                            matchers.Equals(exp_msg))
-            self.assertThat(xlation_mock.called, matchers.Equals(True))
+    def test_dynamic_translated_string_is_Message(self):
+        # Dynamically created message strings are Message objects so that they
+        # are lazy-translated.
+        self.assertIsInstance(_('The resource could not be found.'),
+                              gettextutils.Message)
 
 
 class ServerTest(tests.TestCase):
