@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -17,11 +15,15 @@
 import copy
 
 from keystone.common import sql
+from keystone import config
 from keystone import exception
 from keystone.openstack.common import timeutils
 from keystone import token
 
 
+CONF = config.CONF
+
+
 class TokenModel(sql.ModelBase, sql.DictBase):
     __tablename__ = 'token'
     attributes = ['id', 'expires', 'user_id', 'trust_id']
@@ -37,12 +39,12 @@ class TokenModel(sql.ModelBase, sql.DictBase):
     )
 
 
-class Token(sql.Base, token.Driver):
+class Token(token.Driver):
     # Public interface
     def get_token(self, token_id):
         if token_id is None:
             raise exception.TokenNotFound(token_id=token_id)
-        session = self.get_session()
+        session = sql.get_session()
         token_ref = session.query(TokenModel).get(token_id)
         if not token_ref or not token_ref.valid:
             raise exception.TokenNotFound(token_id=token_id)
@@ -57,20 +59,18 @@ class Token(sql.Base, token.Driver):
 
         token_ref = TokenModel.from_dict(data_copy)
         token_ref.valid = True
-        session = self.get_session()
+        session = sql.get_session()
         with session.begin():
             session.add(token_ref)
-            session.flush()
         return token_ref.to_dict()
 
     def delete_token(self, token_id):
-        session = self.get_session()
+        session = sql.get_session()
         with session.begin():
             token_ref = session.query(TokenModel).get(token_id)
             if not token_ref or not token_ref.valid:
                 raise exception.TokenNotFound(token_id=token_id)
             token_ref.valid = False
-            session.flush()
 
     def delete_tokens(self, user_id, tenant_id=None, trust_id=None,
                       consumer_id=None):
@@ -82,7 +82,7 @@ class Token(sql.Base, token.Driver):
         or the trustor's user ID, so will use trust_id to query the tokens.
 
         """
-        session = self.get_session()
+        session = sql.get_session()
         with session.begin():
             now = timeutils.utcnow()
             query = session.query(TokenModel)
@@ -105,8 +105,6 @@ class Token(sql.Base, token.Driver):
 
                 token_ref.valid = False
 
-            session.flush()
-
     def _tenant_matches(self, tenant_id, token_ref_dict):
         return ((tenant_id is None) or
                 (token_ref_dict.get('tenant') and
@@ -123,7 +121,7 @@ class Token(sql.Base, token.Driver):
                 return False
 
     def _list_tokens_for_trust(self, trust_id):
-        session = self.get_session()
+        session = sql.get_session()
         tokens = []
         now = timeutils.utcnow()
         query = session.query(TokenModel)
@@ -137,7 +135,7 @@ class Token(sql.Base, token.Driver):
         return tokens
 
     def _list_tokens_for_user(self, user_id, tenant_id=None):
-        session = self.get_session()
+        session = sql.get_session()
         tokens = []
         now = timeutils.utcnow()
         query = session.query(TokenModel)
@@ -153,7 +151,7 @@ class Token(sql.Base, token.Driver):
 
     def _list_tokens_for_consumer(self, user_id, consumer_id):
         tokens = []
-        session = self.get_session()
+        session = sql.get_session()
         with session.begin():
             now = timeutils.utcnow()
             query = session.query(TokenModel)
@@ -165,11 +163,12 @@ class Token(sql.Base, token.Driver):
                 token_ref_dict = token_ref.to_dict()
                 if self._consumer_matches(consumer_id, token_ref_dict):
                     tokens.append(token_ref_dict['id'])
-            session.flush()
         return tokens
 
-    def list_tokens(self, user_id, tenant_id=None, trust_id=None,
-                    consumer_id=None):
+    def _list_tokens(self, user_id, tenant_id=None, trust_id=None,
+                     consumer_id=None):
+        if not CONF.token.revoke_by_id:
+            return []
         if trust_id:
             return self._list_tokens_for_trust(trust_id)
         if consumer_id:
@@ -178,7 +177,7 @@ class Token(sql.Base, token.Driver):
             return self._list_tokens_for_user(user_id, tenant_id)
 
     def list_revoked_tokens(self):
-        session = self.get_session()
+        session = sql.get_session()
         tokens = []
         now = timeutils.utcnow()
         query = session.query(TokenModel.id, TokenModel.expires)
@@ -192,11 +191,41 @@ class Token(sql.Base, token.Driver):
             tokens.append(record)
         return tokens
 
-    def flush_expired_tokens(self):
-        session = self.get_session()
+    def token_flush_batch_size(self, dialect):
+        batch_size = 0
+        if dialect == 'ibm_db_sa':
+            # This functionality is limited to DB2, because
+            # it is necessary to prevent the tranaction log
+            # from filling up, whereas at least some of the
+            # other supported databases do not support update
+            # queries with LIMIT subqueries nor do they appear
+            # to require the use of such queries when deleting
+            # large numbers of records at once.
+            batch_size = 100
+            # Limit of 100 is known to not fill a transaction log
+            # of default maximum size while not significantly
+            # impacting the performance of large token purges on
+            # systems where the maximum transaction log size has
+            # been increased beyond the default.
+        return batch_size
 
-        query = session.query(TokenModel)
-        query = query.filter(TokenModel.expires < timeutils.utcnow())
-        query.delete(synchronize_session=False)
+    def flush_expired_tokens(self):
+        session = sql.get_session()
+        dialect = session.bind.dialect.name
+        batch_size = self.token_flush_batch_size(dialect)
+        if batch_size > 0:
+            query = session.query(TokenModel.id)
+            query = query.filter(TokenModel.expires < timeutils.utcnow())
+            query = query.limit(batch_size).subquery()
+            delete_query = (session.query(TokenModel).
+                            filter(TokenModel.id.in_(query)))
+            while True:
+                rowcount = delete_query.delete(synchronize_session=False)
+                if rowcount == 0:
+                    break
+        else:
+            query = session.query(TokenModel)
+            query = query.filter(TokenModel.expires < timeutils.utcnow())
+            query.delete(synchronize_session=False)
 
         session.flush()
