@@ -15,21 +15,18 @@
 """Token provider interface."""
 
 import abc
-import datetime
 
-from keystoneclient.common import cms
 import six
 
 from keystone.common import cache
 from keystone.common import dependency
 from keystone.common import manager
 from keystone import config
+
 from keystone import exception
-from keystone.i18n import _
-from keystone.models import token_model
+from keystone.openstack.common.gettextutils import _
 from keystone.openstack.common import log
 from keystone.openstack.common import timeutils
-from keystone.openstack.common import versionutils
 
 
 CONF = config.CONF
@@ -40,35 +37,21 @@ SHOULD_CACHE = cache.should_cache_fn('token')
 EXPIRATION_TIME = lambda: CONF.token.cache_time
 
 # supported token versions
-V2 = token_model.V2
-V3 = token_model.V3
-VERSIONS = token_model.VERSIONS
+V2 = 'v2.0'
+V3 = 'v3.0'
+VERSIONS = frozenset([V2, V3])
 
 # default token providers
 PKI_PROVIDER = 'keystone.token.providers.pki.Provider'
-PKIZ_PROVIDER = 'keystone.token.providers.pkiz.Provider'
 UUID_PROVIDER = 'keystone.token.providers.uuid.Provider'
 
-_FORMAT_TO_PROVIDER = {
-    'PKI': PKI_PROVIDER,
-    # should not support new options, but PKIZ keeps the option consistent
-    'PKIZ': PKIZ_PROVIDER,
-    'UUID': UUID_PROVIDER
-}
 
-
-def default_expire_time():
-    """Determine when a fresh token should expire.
-
-    Expiration time varies based on configuration (see ``[token] expiration``).
-
-    :returns: a naive UTC datetime.datetime object
-
-    """
-    expire_delta = datetime.timedelta(seconds=CONF.token.expiration)
-    return timeutils.utcnow() + expire_delta
+class UnsupportedTokenVersionException(Exception):
+    """Token version is unrecognizable or unsupported."""
+    pass
 
 
+@dependency.requires('token_api')
 @dependency.optional('revoke_api')
 @dependency.provider('token_provider_api')
 class Manager(manager.Manager):
@@ -79,10 +62,6 @@ class Manager(manager.Manager):
 
     """
 
-    V2 = V2
-    V3 = V3
-    VERSIONS = VERSIONS
-
     @classmethod
     def get_token_provider(cls):
         """Return package path to the configured token provider.
@@ -96,42 +75,42 @@ class Manager(manager.Manager):
         ``provider`` instead.
 
         """
+        if CONF.token.provider is not None:
+            # NOTE(gyee): we are deprecating CONF.signing.token_format. This
+            # code is to ensure the token provider configuration agrees with
+            # CONF.signing.token_format.
+            if (CONF.signing.token_format and
+                    ((CONF.token.provider == PKI_PROVIDER and
+                        CONF.signing.token_format != 'PKI') or
+                        (CONF.token.provider == UUID_PROVIDER and
+                            CONF.signing.token_format != 'UUID'))):
+                raise exception.UnexpectedError(
+                    _('keystone.conf [signing] token_format (deprecated) '
+                      'conflicts with keystone.conf [token] provider'))
+            return CONF.token.provider
+        else:
+            if not CONF.signing.token_format:
+                # No token provider and no format, so use default (PKI)
+                return PKI_PROVIDER
 
-        if CONF.signing.token_format:
-            LOG.warn(_('[signing] token_format is deprecated. '
-                       'Please change to setting the [token] provider '
-                       'configuration value instead'))
-            try:
-
-                mapped = _FORMAT_TO_PROVIDER[CONF.signing.token_format]
-            except KeyError:
+            msg = _('keystone.conf [signing] token_format is deprecated in '
+                    'favor of keystone.conf [token] provider')
+            if CONF.signing.token_format == 'PKI':
+                LOG.warning(msg)
+                return PKI_PROVIDER
+            elif CONF.signing.token_format == 'UUID':
+                LOG.warning(msg)
+                return UUID_PROVIDER
+            else:
                 raise exception.UnexpectedError(
                     _('Unrecognized keystone.conf [signing] token_format: '
                       'expected either \'UUID\' or \'PKI\''))
-            return mapped
-
-        if CONF.token.provider is None:
-            return PKIZ_PROVIDER
-        else:
-            return CONF.token.provider
 
     def __init__(self):
         super(Manager, self).__init__(self.get_token_provider())
 
-    def unique_id(self, token_id):
-        """Return a unique ID for a token.
-
-        The returned value is useful as the primary key of a database table,
-        memcache store, or other lookup table.
-
-        :returns: Given a PKI token, returns it's hashed value. Otherwise,
-                  returns the passed-in value (such as a UUID token ID or an
-                  existing hash).
-        """
-        return cms.cms_hash_token(token_id, mode=CONF.token.hash_algorithm)
-
     def validate_token(self, token_id, belongs_to=None):
-        unique_id = self.unique_id(token_id)
+        unique_id = self.token_api.unique_id(token_id)
         # NOTE(morganfainberg): Ensure we never use the long-form token_id
         # (PKI) as part of the cache_key.
         token = self._validate_token(unique_id)
@@ -151,7 +130,7 @@ class Manager(manager.Manager):
             self.revoke_api.check_token(token_values)
 
     def validate_v2_token(self, token_id, belongs_to=None):
-        unique_id = self.unique_id(token_id)
+        unique_id = self.token_api.unique_id(token_id)
         # NOTE(morganfainberg): Ensure we never use the long-form token_id
         # (PKI) as part of the cache_key.
         token = self._validate_v2_token(unique_id)
@@ -177,18 +156,13 @@ class Manager(manager.Manager):
             return self.check_revocation_v3(token)
 
     def validate_v3_token(self, token_id):
-        unique_id = self.unique_id(token_id)
+        unique_id = self.token_api.unique_id(token_id)
         # NOTE(morganfainberg): Ensure we never use the long-form token_id
         # (PKI) as part of the cache_key.
         token = self._validate_v3_token(unique_id)
         self._is_valid_token(token)
         return token
 
-    @versionutils.deprecated(
-        as_of=versionutils.deprecated.JUNO,
-        what='token_provider_api.check_v2_token',
-        in_favor_of='token_provider_api.validate_v2_token',
-        remove_in=+1)
     def check_v2_token(self, token_id, belongs_to=None):
         """Check the validity of the given V2 token.
 
@@ -199,14 +173,9 @@ class Manager(manager.Manager):
         """
         # NOTE(morganfainberg): Ensure we never use the long-form token_id
         # (PKI) as part of the cache_key.
-        unique_id = self.unique_id(token_id)
+        unique_id = self.token_api.unique_id(token_id)
         self.validate_v2_token(unique_id, belongs_to=belongs_to)
 
-    @versionutils.deprecated(
-        as_of=versionutils.deprecated.JUNO,
-        what='token_provider_api.check_v3_token',
-        in_favor_of='token_provider_api.validate_v3_token',
-        remove_in=+1)
     def check_v3_token(self, token_id):
         """Check the validity of the given V3 token.
 
@@ -216,7 +185,7 @@ class Manager(manager.Manager):
         """
         # NOTE(morganfainberg): Ensure we never use the long-form token_id
         # (PKI) as part of the cache_key.
-        unique_id = self.unique_id(token_id)
+        unique_id = self.token_api.unique_id(token_id)
         self.validate_v3_token(unique_id)
 
     @cache.on_arguments(should_cache_fn=SHOULD_CACHE,
@@ -305,7 +274,7 @@ class Provider(object):
         :returns: token version string
         :raises: keystone.token.provider.UnsupportedTokenVersionException
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def issue_v2_token(self, token_ref, roles_ref=None, catalog_ref=None):
@@ -319,7 +288,7 @@ class Provider(object):
         :type catalog_ref: dict
         :returns: (token_id, token_data)
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def issue_v3_token(self, user_id, method_names, expires_at=None,
@@ -345,7 +314,7 @@ class Provider(object):
         :type include_catalog: boolean
         :returns: (token_id, token_data)
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def revoke_token(self, token_id):
@@ -355,7 +324,7 @@ class Provider(object):
         :type token_id: string
         :returns: None.
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def validate_token(self, token_id):
@@ -368,7 +337,7 @@ class Provider(object):
         :returns: token_data
         :raises: keystone.exception.TokenNotFound
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def validate_v2_token(self, token_id):
@@ -382,7 +351,7 @@ class Provider(object):
         :raises: keystone.exception.TokenNotFound
 
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def validate_v3_token(self, token_id):
@@ -393,7 +362,7 @@ class Provider(object):
         :returns: token data
         :raises: keystone.exception.TokenNotFound
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
 
     @abc.abstractmethod
     def _get_token_id(self, token_data):
@@ -403,4 +372,4 @@ class Provider(object):
         :type token_data: dict
         returns: token identifier
         """
-        raise exception.NotImplemented()  # pragma: no cover
+        raise exception.NotImplemented()
