@@ -34,9 +34,13 @@ LOG = log.getLogger(__name__)
 class Provider(common.BaseProvider):
     def _get_token_id(self, token_data):
         try:
-            token_id = cms.cms_sign_token(json.dumps(token_data),
-                                          CONF.signing.certfile,
-                                          CONF.signing.keyfile)
+            # force conversion to a string as the keystone client cms code
+            # produces unicode.  This can be removed if the client returns
+            # str()
+            # TODO(ayoung): Make to a byte_str for Python3
+            token_id = str(cms.cms_sign_token(json.dumps(token_data),
+                                              CONF.signing.certfile,
+                                              CONF.signing.keyfile))
             return token_id
         except environment.subprocess.CalledProcessError:
             LOG.exception(_('Unable to sign token'))
