@@ -33,9 +33,9 @@ class TrustModel(sql.ModelBase, sql.DictBase):
                   'project_id', 'impersonation', 'expires_at',
                   'remaining_uses']
     id = sql.Column(sql.String(64), primary_key=True)
-    # user id of owner
+    #user id Of owner
     trustor_user_id = sql.Column(sql.String(64), nullable=False,)
-    # user_id of user allowed to consume this preauth
+    #user_id of user allowed to consume this preauth
     trustee_user_id = sql.Column(sql.String(64), nullable=False)
     project_id = sql.Column(sql.String(64))
     impersonation = sql.Column(sql.Boolean, nullable=False)
@@ -55,7 +55,8 @@ class TrustRole(sql.ModelBase):
 class Trust(trust.Driver):
     @sql.handle_conflicts(conflict_type='trust')
     def create_trust(self, trust_id, trust, roles):
-        with sql.transaction() as session:
+        session = sql.get_session()
+        with session.begin():
             ref = TrustModel.from_dict(trust)
             ref['id'] = trust_id
             if ref.get('expires_at') and ref['expires_at'].tzinfo is not None:
@@ -80,7 +81,6 @@ class Trust(trust.Driver):
 
     @sql.handle_conflicts(conflict_type='trust')
     def consume_use(self, trust_id):
-
         for attempt in range(MAXIMUM_CONSUME_ATTEMPTS):
             with sql.transaction() as session:
                 try:
@@ -171,7 +171,8 @@ class Trust(trust.Driver):
 
     @sql.handle_conflicts(conflict_type='trust')
     def delete_trust(self, trust_id):
-        with sql.transaction() as session:
+        session = sql.get_session()
+        with session.begin():
             trust_ref = session.query(TrustModel).get(trust_id)
             if not trust_ref:
                 raise exception.TrustNotFound(trust_id=trust_id)
